@@ -41,8 +41,7 @@ bal_accuracy.data.frame <- function(data,
     estimate = !!enquo(estimate),
     estimator = estimator,
     na_rm = na_rm,
-    event_level = event_level,
-    ... = ...
+    event_level = event_level
   )
 
 }
@@ -96,8 +95,7 @@ bal_accuracy_vec <- function(truth,
     estimate = estimate,
     na_rm = na_rm,
     estimator = estimator,
-    cls = "factor",
-    ...
+    cls = "factor"
   )
 }
 
@@ -112,8 +110,7 @@ bal_accuracy_table_impl <- function(data, estimator, event_level) {
 }
 
 bal_accuracy_binary <- function(data, event_level) {
-  # (sens + spec) / 2
-  ( recall_binary(data, event_level) + spec_binary(data, event_level) ) / 2
+  ( sens_binary(data, event_level) + spec_binary(data, event_level) ) / 2
 }
 
 # Urbanowicz 2015 ExSTraCS 2.0 description and evaluation of a scalable learning.pdf
