@@ -54,8 +54,7 @@ iic.data.frame <- function(data, truth, estimate, na_rm = TRUE, ...) {
     data = data,
     truth = !!enquo(truth),
     estimate = !!enquo(estimate),
-    na_rm = na_rm,
-    ... = ...
+    na_rm = na_rm
   )
 
 }
@@ -83,8 +82,7 @@ iic_vec <- function(truth, estimate, na_rm = TRUE, ...) {
     truth = truth,
     estimate = estimate,
     na_rm = na_rm,
-    cls = "numeric",
-    ...
+    cls = "numeric"
   )
 
 }
