@@ -33,8 +33,7 @@ mae.data.frame <- function(data, truth, estimate, na_rm = TRUE, ...) {
     data = data,
     truth = !!enquo(truth),
     estimate = !!enquo(estimate),
-    na_rm = na_rm,
-    ... = ...
+    na_rm = na_rm
   )
 
 }
@@ -52,8 +51,7 @@ mae_vec <- function(truth, estimate, na_rm = TRUE, ...) {
     truth = truth,
     estimate = estimate,
     na_rm = na_rm,
-    cls = "numeric",
-    ...
+    cls = "numeric"
   )
 
 }
