@@ -37,8 +37,7 @@ mape.data.frame <- function(data, truth, estimate, na_rm = TRUE, ...) {
     data = data,
     truth = !!enquo(truth),
     estimate = !!enquo(estimate),
-    na_rm = na_rm,
-    ... = ...
+    na_rm = na_rm
   )
 
 }
@@ -56,8 +55,7 @@ mape_vec <- function(truth, estimate, na_rm = TRUE, ...) {
     truth = truth,
     estimate = estimate,
     na_rm = na_rm,
-    cls = "numeric",
-    ...
+    cls = "numeric"
   )
 
 }
