@@ -17,7 +17,6 @@
 #' @template event_first
 #'
 #' @inheritParams pr_auc
-#' @param object The `pr_df` data frame returned from `pr_curve()`.
 #'
 #' @return
 #' A tibble with class `pr_df` or `pr_grouped_df` having
@@ -72,31 +71,18 @@ pr_curve.data.frame <- function(data,
                                 na_rm = TRUE,
                                 event_level = yardstick_event_level()) {
   estimate <- dots_to_estimate(data, !!! enquos(...))
-  truth <- enquo(truth)
 
-  validate_not_missing(truth, "truth")
-
-  # Explicit handling of length 1 character vectors as column names
-  truth <- handle_chr_names(truth, colnames(data))
-
-  res <- dplyr::do(
-    data,
-    pr_curve_vec(
-      truth = rlang::eval_tidy(truth, data = .),
-      estimate = rlang::eval_tidy(estimate, data = .),
-      na_rm = na_rm,
-      event_level = event_level
-    )
+  result <- metric_summarizer(
+    metric_nm = "pr_curve",
+    metric_fn = pr_curve_vec,
+    data = data,
+    truth = !!enquo(truth),
+    estimate = !!estimate,
+    na_rm = na_rm,
+    event_level = event_level
   )
 
-  if (dplyr::is_grouped_df(res)) {
-    class(res) <- c("grouped_pr_df", "pr_df", class(res))
-  }
-  else {
-    class(res) <- c("pr_df", class(res))
-  }
-
-  res
+  curve_finalize(result, data, "pr_df", "grouped_pr_df")
 }
 
 # Undecided of whether to export this or not
@@ -175,7 +161,6 @@ pr_curve_multiclass <- function(truth, estimate) {
 
 
 # Dynamically exported
-#' @rdname pr_curve
 autoplot.pr_df <- function(object, ...) {
 
   `%+%` <- ggplot2::`%+%`
