@@ -1,7 +1,3 @@
-context("F Measure")
-
-# ------------------------------------------------------------------------------
-
 test_that('Two class - Powers paper', {
   lst <- data_powers()
   tabl_2_1 <- lst$tabl_2_1
@@ -10,17 +6,17 @@ test_that('Two class - Powers paper', {
   expect_equal(
     f_meas(df_2_1, truth = "truth", estimate = "prediction")[[".estimate"]],
     0.5882353,
-    tol = 0.0001
+    tolerance = 0.0001
   )
   expect_equal(
     f_meas(tabl_2_1)[[".estimate"]],
     0.5882353,
-    tol = 0.0001
+    tolerance = 0.0001
   )
   expect_equal(
     f_meas(df_2_1, truth = truth, estimate = pred_na)[[".estimate"]],
     0.5652174,
-    tol = 0.0001
+    tolerance = 0.0001
   )
 })
 
@@ -42,31 +38,27 @@ test_that("`event_level = 'second'` works", {
 # Issue #77
 
 test_that("`NA` values propagate from binary `precision()`", {
-
   truth <- factor(c(rep("a", 2), rep("b", 2)))
   estimate <- factor(rep("b", length(truth)), levels(truth))
 
-  expect_warning(
-    expect_equal(
-      precision_vec(truth, estimate),
-      f_meas_vec(truth, estimate)
-    )
-  )
+  expect_snapshot({
+    out <- precision_vec(truth, estimate)
+    expect <- f_meas_vec(truth, estimate)
+  })
 
+  expect_identical(out, expect)
 })
 
 test_that("`NA` values propagate from binary `recall()`", {
-
   estimate <- factor(c(rep("a", 2), rep("b", 2)))
   truth <- factor(rep("b", length(estimate)), levels(estimate))
 
-  expect_warning(
-    expect_equal(
-      recall_vec(truth, estimate),
-      f_meas_vec(truth, estimate)
-    )
-  )
+  expect_snapshot({
+    out <- recall_vec(truth, estimate)
+    expect <- f_meas_vec(truth, estimate)
+  })
 
+  expect_identical(out, expect)
 })
 
 # ------------------------------------------------------------------------------
@@ -76,16 +68,11 @@ test_that("Binary `f_meas()` returns `NA` with a warning when recall is undefine
   truth    <- factor(c("b", "b"), levels = levels)
   estimate <- factor(c("a", "b"), levels = levels)
 
-  expect_warning(
-    expect_equal(
-      f_meas_vec(truth, estimate),
-      NA_real_
-    )
+  expect_snapshot(
+    out <- f_meas_vec(truth, estimate)
   )
 
-  cnd <- rlang::catch_cnd(f_meas_vec(truth, estimate))
-  expect_known_output(cat(cnd$message), test_path("test-class-f_meas-recall-warning-binary.txt"), print = TRUE)
-  expect_s3_class(cnd, "yardstick_warning_recall_undefined_binary")
+  expect_identical(out, NA_real_)
 })
 
 test_that("Binary `f_meas()` returns `NA` with a warning when precision is undefined (tp + fp = 0) (#98)", {
@@ -93,16 +80,11 @@ test_that("Binary `f_meas()` returns `NA` with a warning when precision is undef
   truth <- factor("a", levels = levels)
   estimate <- factor("b", levels = levels)
 
-  expect_warning(
-    expect_equal(
-      f_meas_vec(truth, estimate),
-      NA_real_
-    )
+  expect_snapshot(
+    out <- f_meas_vec(truth, estimate)
   )
 
-  cnd <- rlang::catch_cnd(f_meas_vec(truth, estimate))
-  expect_known_output(cat(cnd$message), test_path("test-class-f_meas-precision-warning-binary.txt"), print = TRUE)
-  expect_s3_class(cnd, "yardstick_warning_precision_undefined_binary")
+  expect_identical(out, NA_real_)
 })
 
 test_that("Multiclass `f_meas()` returns averaged value with `NA`s removed + a warning when recall is undefined (tp + fn = 0) (#98)", {
@@ -110,11 +92,12 @@ test_that("Multiclass `f_meas()` returns averaged value with `NA`s removed + a w
 
   truth    <- factor(c("a", "b", "b"), levels = levels)
   estimate <- factor(c("a", "b", "c"), levels = levels)
-  expect_warning(expect_equal(f_meas_vec(truth, estimate), 5/6))
 
-  cnd <- rlang::catch_cnd(f_meas_vec(truth, estimate))
-  expect_known_output(cat(cnd$message), test_path("test-class-f_meas-recall-warning-multiclass.txt"), print = TRUE)
-  expect_s3_class(cnd, "yardstick_warning_recall_undefined_multiclass")
+  expect_snapshot(
+    out <- f_meas_vec(truth, estimate)
+  )
+
+  expect_identical(out, 5/6)
 })
 
 test_that("Multiclass `f_meas()` returns averaged value with `NA`s removed + a warning when precision is undefined (tp + fn = 0) (#98)", {
@@ -122,11 +105,12 @@ test_that("Multiclass `f_meas()` returns averaged value with `NA`s removed + a w
 
   truth    <- factor(c("a", "b", "c"), levels = levels)
   estimate <- factor(c("a", "b", "b"), levels = levels)
-  expect_warning(expect_equal(f_meas_vec(truth, estimate), 5/6))
 
-  cnd <- rlang::catch_cnd(f_meas_vec(truth, estimate))
-  expect_known_output(cat(cnd$message), test_path("test-class-f_meas-precision-warning-multiclass.txt"), print = TRUE)
-  expect_s3_class(cnd, "yardstick_warning_precision_undefined_multiclass")
+  expect_snapshot(
+    out <- f_meas_vec(truth, estimate)
+  )
+
+  expect_identical(out, 5/6)
 })
 
 test_that("`NA` is still returned if there are some undefined recall values but `na.rm = FALSE`", {
