@@ -1,7 +1,3 @@
-context("Recall")
-
-# ------------------------------------------------------------------------------
-
 test_that('Two class - Powers paper', {
   lst <- data_powers()
   tabl_2_1 <- lst$tabl_2_1
@@ -42,16 +38,8 @@ test_that("Binary `recall()` returns `NA` with a warning when undefined (tp + fn
   truth    <- factor(c("b", "b"), levels = levels)
   estimate <- factor(c("a", "b"), levels = levels)
 
-  expect_warning(
-    expect_equal(
-      recall_vec(truth, estimate),
-      NA_real_
-    )
-  )
-
-  cnd <- rlang::catch_cnd(recall_vec(truth, estimate))
-  expect_known_output(cat(cnd$message), test_path("test-class-recall-warning-binary.txt"), print = TRUE)
-  expect_s3_class(cnd, "yardstick_warning_recall_undefined_binary")
+  expect_snapshot(out <- recall_vec(truth, estimate))
+  expect_identical(out, NA_real_)
 })
 
 test_that("Multiclass `recall()` returns averaged value with `NA`s removed + a warning when undefined (tp + fn = 0) (#98)", {
@@ -63,11 +51,9 @@ test_that("Multiclass `recall()` returns averaged value with `NA`s removed + a w
   # When `c` is the event we get a warning = NA  = (tp = 0, fn = 0)
   truth    <- factor(c("a", "d", "d"), levels = levels)
   estimate <- factor(c("a", "d", "c"), levels = levels)
-  expect_warning(expect_equal(recall_vec(truth, estimate), 0.75))
 
-  cnd <- rlang::catch_cnd(recall_vec(truth, estimate))
-  expect_known_output(cat(cnd$message), test_path("test-class-recall-warning-multiclass.txt"), print = TRUE)
-  expect_s3_class(cnd, "yardstick_warning_recall_undefined_multiclass")
+  expect_snapshot(out <- recall_vec(truth, estimate))
+  expect_identical(out, 0.75)
 })
 
 test_that("`NA` is still returned if there are some undefined recall values but `na.rm = FALSE`", {
