@@ -1,5 +1,3 @@
-context("AUNU")
-
 test_that("AUNU is equivalent to macro estimator", {
   hpc_f1 <- data_hpc_fold1()
 
@@ -10,11 +8,9 @@ test_that("AUNU is equivalent to macro estimator", {
 })
 
 test_that("AUNU errors on binary case", {
-  expect_error(
-    roc_aunu(two_class_example, truth, Class1),
-    "The number of levels in",
-    class = "dplyr_error"
-  )
+  expect_snapshot((expect_error(
+    roc_aunu(two_class_example, truth, Class1)
+  )))
 })
 
 test_that("AUNU results match mlr for soybean example", {
